# Options
.onLoad <- function(libname, pkgname){
options(soc.ca.colors = c("#E41A1C", "#377EB8", "#4DAF4A", "#984EA3", "#FF7F00", "#FFFF33", 
                          "#A65628", "#F781BF", "#999999", "#7FC97F", "#BEAED4", "#FDC086", "#FFFF99", "#386CB0", "#F0027F", 
                          "#BF5B17", "#666666", "#FF0000FF", "#FF2600FF", "#FF4D00FF", "#FF7300FF", "#FF9900FF", 
                          "#FFBF00FF", "#FFE500FF", "#F2FF00FF", "#CCFF00FF", "#A6FF00FF", 
                          "#80FF00FF", "#59FF00FF", "#33FF00FF", "#0DFF00FF", "#00FF19FF", 
                          "#00FF40FF", "#00FF66FF", "#00FF8CFF", "#00FFB2FF", "#00FFD9FF", 
                          "#00FFFFFF", "#00D9FFFF", "#00B3FFFF", "#008CFFFF", "#0066FFFF", 
                          "#0040FFFF", "#001AFFFF", "#0D00FFFF", "#3300FFFF", "#5900FFFF", 
                          "#7F00FFFF", "#A600FFFF", "#CC00FFFF", "#F200FFFF", "#FF00E6FF", 
                          "#FF00BFFF", "#FF0099FF", "#FF0073FF", "#FF004DFF", "#FF0026FF"))
options(soc.ca.gradient = c(low = "papayawhip", high = "darkblue"))
options(soc.ca.shape    = c(21, 22, 23, 24, 25, 6, 0, 1, 2, 3, 4, 5, 7, 8, 9, 10,
                            12, 15, 16, 17, 18, 42, 45, 61, 48, 50:120))
options(soc.ca.colors.binary = c("black", "#d53e4f"))
options(soc.ca.red = "#d53e4f")
update_geom_defaults("density2d",   list(color = "#d53e4f"))
}

################################################################################


